@@ -21,11 +21,8 @@ void
 sjog_brightness_check_jog_position(int jog)
 {
 
-#ifdef DEBUG
-   fprintf(stdout,
-           "sjog_brightness_check_jog_position: currentBrightness=%d\n",
-           currentBrightness);
-#endif
+
+   D("currentBrightness=%d\n", currentBrightness);
 
    switch (jog)
    {
@@ -72,7 +69,7 @@ sjog_get_brightness()
    int brightness = 50;
    char buf[10];
 
-   if ((pin = popen("spicctrl -B", "r")))
+   if ((pin = popen("setbrightness --read", "r")))
    {
       if (fgets(buf, sizeof(buf) - 1, pin) != NULL)
       {
@@ -80,9 +77,8 @@ sjog_get_brightness()
       }
       pclose(pin);
    }
-#ifdef DEBUG
-   fprintf(stdout, "sjog_get_brightness: val=%d\n", brightness);
-#endif
+
+   D("val=%d\n", brightness);
 
    if (reverseBrightness)
       brightness = 100 - brightness;
@@ -115,11 +111,9 @@ sjog_set_brightness(int brightness)
    brightness = (brightness < 0 ? 0 : (brightness > 255 ? 255 : brightness));
 
    /* setup the command line, setbrightness must be in PATH */
-   cmd = g_strdup_printf("spicctrl -b %d", brightness);
+   cmd = g_strdup_printf("setbrightness %d", brightness);
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_set_brightness: cmd=%s\n", cmd);
-#endif
+   D("cmd=%s\n", cmd);
 
    /* execute setbrightness */
    system(cmd);
@@ -144,8 +138,9 @@ sjog_brightness_show()
    if (brightnessWindow == NULL)
       init_brightness_gui();
 
-   /* forces brightness to default value */
-   sjog_set_brightness(currentBrightness);
+   /* set the progress bar to the current brightness value */
+   gtk_progress_set_value(GTK_PROGRESS(brightnessProgressBar),
+                          sjog_get_brightness());
 
    gtk_widget_show_all(brightnessWindow);
 
@@ -202,7 +197,7 @@ init_brightness_gui()
    brightnessWindow = gtk_window_new(GTK_WINDOW_DIALOG);
    gtk_container_set_border_width(GTK_CONTAINER(brightnessWindow), 10);
 
-   sjog_window_set_position(GTK_WINDOW(brightnessWindow));
+   gtk_window_set_position(GTK_WINDOW(brightnessWindow), GTK_WIN_POS_CENTER);
 
    gtk_window_set_title(GTK_WINDOW(brightnessWindow), "S-Jog: Brightness");
    gtk_signal_connect(GTK_OBJECT(brightnessWindow), "delete-event",
