@@ -7,9 +7,7 @@ int
 sjog_brightness_timer_callback(gpointer * data)
 {
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_brightness_timer_callback\n");
-#endif
+   D_ENTER;
 
    sjog_brightness_hide();
 
@@ -27,9 +25,7 @@ sjog_brightness_signal_delete_event_callback(GtkWidget * widget,
                                              gpointer * data)
 {
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_brightness_signal_delete_event_callback\n");
-#endif
+   D_ENTER;
 
    sjog_brightness_hide();
 
