@@ -1,6 +1,7 @@
 #include "sjog.h"
 #include "sjog_list.h"
 #include "sjog_list_callbacks.h"
+#include "sjog_enlightenment.h"
 
 /* -------------------------------------------------------------------------- */
 
@@ -12,16 +13,39 @@ void
 sjog_list_init()
 {
    /* call the parsing of the config file */
-   sjog_init_list_entries();
+   if (eMenu)
+   sjog_init_tree_entries();
+   else
+      sjog_init_list_entries();
 
    listTimer = 0;
    /* create the list window and register callbacks */
-   listWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+   listWindow =
+      windowsAreTransient ? gtk_window_new(GTK_WINDOW_DIALOG) :
+      gtk_window_new(GTK_WINDOW_TOPLEVEL);
    gtk_window_set_title(GTK_WINDOW(listWindow), "S-Jog");
+
    gtk_signal_connect(GTK_OBJECT(listWindow), "delete-event",
                       GTK_SIGNAL_FUNC(sjog_list_signal_delete_event_callback),
                       NULL);
 
+   /* TT - This callback is used to determine where to move the window
+    * just before it's shown, and just after the widget has been allocated.
+    */
+   gtk_signal_connect(GTK_OBJECT(listWindow), "realize",
+                      GTK_SIGNAL_FUNC(sjog_list_signal_realize_callback),
+                      NULL);
+   
+   /* creates a 1 column width list */
+   cmdListUI = gtk_clist_new(1);
+   gtk_clist_set_column_auto_resize(GTK_CLIST(cmdListUI), 0, TRUE);
+
+   /* be warned when a row is selected */
+   gtk_signal_connect(GTK_OBJECT(cmdListUI), "select-row",
+                      GTK_SIGNAL_FUNC(sjog_list_row_selected_callback), NULL);
+
+   gtk_container_add(GTK_CONTAINER(listWindow), cmdListUI);
+
 }
 
 /* -------------------------------------------------------------------------- */
@@ -31,7 +55,7 @@ sjog_list_init()
  * @arg list the list model.
  */
 void
-sjog_list_set_list(GList * list)
+sjog_list_set_list()
 {
    guint length, i = 0;      /* commands list length and loop index */
    sjog_cmd_t *cmd;          /* temporary pointer for commands insertion loop */
@@ -41,14 +65,6 @@ sjog_list_set_list(GList * list)
    /* default is to select 1st item */
    selectedIndex = 0;
 
-   /* creates a 1 column width list */
-   cmdListUI = gtk_clist_new(1);
-   gtk_clist_set_column_auto_resize(GTK_CLIST(cmdListUI), 0, TRUE);
-
-   /* be warned when a row is selected */
-   gtk_signal_connect(GTK_OBJECT(cmdListUI), "select-row",
-                      GTK_SIGNAL_FUNC(sjog_list_row_selected_callback), NULL);
-
    /* get the number of items to put in the list */
    length = g_list_length(list);
 
@@ -58,9 +74,7 @@ sjog_list_set_list(GList * list)
       exit(2);
    }
 
-#ifdef DEBUG
-   fprintf(stdout, "list contains %d items\n", length);
-#endif
+   D("list contains %d items\n", length);
 
    /* loops over the items and add them to the list */
    for (i = 0; i <= length - 1; i++)
@@ -73,8 +87,6 @@ sjog_list_set_list(GList * list)
    /* select the 1st item */
    gtk_clist_select_row(GTK_CLIST(cmdListUI), selectedIndex, 0);
 
-   gtk_container_add(GTK_CONTAINER(listWindow), cmdListUI);
-
 }
 
 /* -------------------------------------------------------------------------- */
@@ -86,20 +98,21 @@ void
 sjog_list_show()
 {
 
-#ifdef DEBUG
-   fprintf(stderr, "sjog_list_show\n");
-#endif
+   D_ENTER;
 
    if (listWindow == NULL)
    {
       sjog_list_init();
-      sjog_list_set_list(list);
+      if (eMenu)
+         sjog_tree_set_list();
+      else
+         sjog_list_set_list();
    }
 
    if (resetMenu == TRUE)
    {
-   	/* select the 1st item */
-	gtk_clist_select_row(GTK_CLIST(cmdListUI), 0, 0);
+      /* select the 1st item */
+      gtk_clist_select_row(GTK_CLIST(cmdListUI), 0, 0);
    }
 
    if (!GTK_WIDGET_VISIBLE(listWindow))
@@ -108,7 +121,10 @@ sjog_list_show()
       sjog_set_mode(SJOG_MODE_LIST);
 
       /* show the window */
-      sjog_window_set_position(GTK_WINDOW(listWindow));
+      /* sjog_window_set_position(GTK_WINDOW(listWindow)); */
+      /* TT - The above sjog_window_set_position() function is now depracated,
+       * as the functionaliy has been moved into the "realize" event callback
+       */
       gtk_widget_show_all(listWindow);
 
       /* reset the window hidding timer */
@@ -125,9 +141,7 @@ void
 sjog_list_hide()
 {
 
-#ifdef DEBUG
-   fprintf(stderr, "sjog_list_hide\n");
-#endif
+   D_ENTER;
 
    gtk_timeout_remove(listTimer);
    gtk_widget_hide_all(listWindow);
@@ -144,9 +158,7 @@ void
 sjog_list_reset_timer()
 {
 
-#ifdef DEBUG
-   fprintf(stderr, "sjog_list_reset_timer\n");
-#endif
+   D_ENTER;
 
    if (listTimer != 0)
       gtk_timeout_remove(listTimer);
@@ -174,6 +186,9 @@ sjog_list_check_jog_position(int jog)
      case JOG_TOP:
         sjog_list_select_previous();
         break;
+     case JOG_BACK:
+   sjog_list_go_back();
+   break;
    }
 }
 
@@ -186,40 +201,42 @@ sjog_list_check_jog_position(int jog)
 void
 sjog_list_exec_cmd()
 {
-   sjog_cmd_t *sjog_cmd;     /* sjog_cmd to execute */
+   sjog_cmd_t *sjog_cmd;               /* sjog_cmd to execute */
    static sjog_cmd_t *prev_cmd = NULL; /* previously executed command */
-   GList *list_element;      /* glib element that contains the cmd */
-   gchar *cmd;               /* cmd string to execute */
+   GList *list_element;                /* glib element that contains the cmd */
+   GNode *tree_element;                /* glib element that contains the cmd */
+   gchar *cmd;                         /* cmd string to execute */
 
    /* remove the timer and hide the window */
    sjog_list_hide();
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_list_exec_cmd\n");
-#endif
+   D_ENTER;
 
-   list_element = g_list_nth(list, selectedIndex);
-   sjog_cmd = (sjog_cmd_t *) list_element->data;
+   if (eMenu)
+   {
+      tree_element = g_node_nth_child(currentTreeNode, selectedIndex);
+      sjog_cmd = (sjog_cmd_t *) tree_element->data;
+   }
+   else
+   {
+      list_element = g_list_nth(list, selectedIndex);
+      sjog_cmd = (sjog_cmd_t *) list_element->data;
+   }
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_list_exec_cmd: sjog_cmd->path = %s\n",
-           sjog_cmd->path);
-#endif
+   D("sjog_cmd->path = %s\n", sjog_cmd->path);
 
    /* redo allows execution of the last executed command  */
    if (strcmp(sjog_cmd->path, "redo") == 0) {
-      if (prev_cmd == NULL) /* no previous command */
-	 return;
+
+      /* no previous command */
+      if (prev_cmd == NULL) return;
+
       sjog_cmd = prev_cmd;
    }
    else {
       prev_cmd = sjog_cmd;
    }
 
-   /* hide does nothing and makes the menu disappear */
-   if (strcmp(sjog_cmd->path, "hide") == 0) {
-     return;
-   }
 
    /* enter brightness mode */
    if (strcmp(sjog_cmd->path, "brightness") == 0)
@@ -234,13 +251,40 @@ sjog_list_exec_cmd()
       sjog_set_mode(SJOG_MODE_VOLUME);
       sjog_volume_show();
    }
+   
+   else if (eMenu && sjog_cmd->type == SJOG_CMD_TYPE_MENU)
+   {
+      sjog_list_reset_timer();
+
+      /* return to parent menu if special "parent" item is selected */
+      if (strcmp(sjog_cmd->path, "parent") == 0)
+      {
+         sjog_list_go_back();
+
+      }
+
+      /* enter a new menu only if there is something in it */
+      else if (g_node_n_children(tree_element))
+      {
+         gtk_clist_clear(GTK_CLIST(cmdListUI));
+         currentTreeNode = tree_element;
+         sjog_tree_set_list();
+      }
+
+      /* force re-display */
+      sjog_list_show();
+   }
+
+   /* hide does nothing and makes the menu disappear */
+   else if (strcmp(sjog_cmd->path, "hide") == 0) {
+      return;
+   }
+
    else
    {
       cmd = g_strdup_printf("%s&", sjog_cmd->path);
 
-#ifdef DEBUG
-      fprintf(stdout, "sjog_list_exec_cmd: cmd = %s\n", cmd);
-#endif
+      D("cmd = %s\n", cmd);
 
       /* launch the command */
       system(cmd);
@@ -251,22 +295,58 @@ sjog_list_exec_cmd()
 
 /* -------------------------------------------------------------------------- */
 
+
+void
+sjog_list_go_back()
+{
+   guint index;
+   
+        if (eMenu)
+        {
+
+      D_ENTER;
+
+                if (currentTreeNode->parent)
+                {
+         /* force selected index */
+         index = g_node_child_position(currentTreeNode->parent, currentTreeNode);
+                        sjog_list_reset_timer();
+                        gtk_clist_clear(GTK_CLIST(cmdListUI));
+                        currentTreeNode = currentTreeNode->parent;
+                        sjog_tree_set_list();
+
+                        /* force re-display */
+                        sjog_list_hide();
+                        sjog_list_show();
+         
+         gtk_clist_select_row(GTK_CLIST(cmdListUI), index, 0);
+                }
+      else
+         sjog_list_hide();
+        }
+}
+
+
 /*
  * Selects the next item in the application list.
  */
 void
 sjog_list_select_next()
 {
+   guint length;
+
+   if (eMenu)
+      length = g_node_n_children(currentTreeNode);
+   else
+      length = g_list_length(list);
 
    /* if we hit bottom, go to top */
-   if (selectedIndex == (g_list_length(list) - 1))
+   if (selectedIndex == (length - 1))
       selectedIndex = 0;
    else
       selectedIndex++;
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_list_select_next: %d\n", selectedIndex);
-#endif
+   D("selectedIndex=%d\n", selectedIndex);
 
    gtk_clist_select_row(GTK_CLIST(cmdListUI), selectedIndex, 0);
    sjog_list_reset_timer();
@@ -281,17 +361,28 @@ sjog_list_select_next()
 void
 sjog_list_select_previous()
 {
+   guint length;
+
+   if (eMenu)
+      length = g_node_n_children(currentTreeNode);
+   else
+      length = g_list_length(list);
 
    /* if we hit top, go to bottom */
    if (selectedIndex == 0)
-      selectedIndex = g_list_length(list) - 1;
+      selectedIndex = length - 1;
    else
       selectedIndex--;
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_list_select_previous: %d\n", selectedIndex);
-#endif
+   D("selectedIndex=%d\n", selectedIndex);
 
    gtk_clist_select_row(GTK_CLIST(cmdListUI), selectedIndex, 0);
    sjog_list_reset_timer();
 }
+
+/*
+ * modelines
+ * ex:set ai ts=3 sw=3:
+ * ei:set itab=spaces noat:
+ * vim:set et:
+ */
