@@ -5,22 +5,15 @@
 
 /* -------------------------------------------------------------------------- */
 
-GtkWidget *listWindow;
-GtkWidget *cmdListUI;
-guint listTimer;
-guint selectedIndex;
-GList *list;
-
-/* -------------------------------------------------------------------------- */
-
 void sjog_list_init();
-void sjog_list_set_list(GList * list);
+void sjog_list_set_list();
 void sjog_list_show();
 void sjog_list_hide();
 void sjog_list_check_jog_position(int jog);
 void sjog_list_exec_cmd();
 void sjog_list_select_next();
 void sjog_list_select_previous();
+void sjog_list_go_back();
 void sjog_list_reset_timer();
 
 #endif
