@@ -9,4 +9,8 @@ int sjog_list_signal_delete_event_callback(GtkWidget * widget,
 void sjog_list_row_selected_callback(GtkWidget * widget, gint row, gint col,
                                      GdkEventButton * event, gpointer * data);
 
+/* TT - Added this function to properly move the window before it is displayed
+ */
+int sjog_list_signal_realize_callback(GtkWidget * widget);
+
 #endif
