@@ -40,9 +40,7 @@ void
 sjog_scroll_check_jog_position(int jog)
 {
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_scroll_check_jog_position\n");
-#endif
+   D_ENTER;
 
    if (disp == NULL)
       sjog_scroll_init();
@@ -166,55 +164,3 @@ sjog_scroll_down()
    XTestGrabControl(disp, False);
 
 }
-
-
-/* Added for U1 */
-void
-sjog_button_faketap(int no)
-{
-   if (disp == NULL)
-      sjog_scroll_init();
-
-   XTestGrabControl(disp, True);
-
-   XTestFakeButtonEvent(disp, no, True, CurrentTime);
-   XTestFakeButtonEvent(disp, no, False, 10);
-
-   XSync(disp, False);
-   XTestGrabControl(disp, False);
-
-}
-
-void
-sjog_button_fakepress(int no)
-{
-   if (disp == NULL)
-      sjog_scroll_init();
-
-   XTestGrabControl(disp, True);
-
-   XTestFakeButtonEvent(disp, no, True, CurrentTime);
-//   XTestFakeButtonEvent(disp, no, False, 30);
-
-   XSync(disp, False);
-   XTestGrabControl(disp, False);
-
-}
-
-void
-sjog_button_fakerelease(int no)
-{
-   if (disp == NULL)
-      sjog_scroll_init();
-
-   if ( no != 0 )
-   {
-     XTestGrabControl(disp, True);
-
-     XTestFakeButtonEvent(disp, no, False, CurrentTime);
-
-     XSync(disp, False);
-     XTestGrabControl(disp, False);
-   }
-
-}
