@@ -34,14 +34,7 @@
 #define SONYPI_EVENT_FNKEY_S            29
 #define SONYPI_EVENT_FNKEY_B            30
 #define SONYPI_EVENT_BLUETOOTH_PRESSED      31
-
-#define SONYPI_EVENT_BACK_PRESSED		35
-#define SONYPI_EVENT_LID_CLOSED			36
-#define SONYPI_EVENT_LID_OPENED			37
-#define SONYPI_EVENT_HELP_PRESSED		40
-#define SONYPI_EVENT_FNKEY            		41
-#define SONYPI_EVENT_FNKEY_ZOOM			50
-#define SONYPI_EVENT_FNKEY_THUMBPHRASE		51
+#define SONYPI_EVENT_JOGDIAL_BACK_PRESSED   35
 
 gint sonypi_fd;
 fd_set sonypi_fdset;
