@@ -20,9 +20,7 @@ sjog_spic_read(gpointer * data)
 
    gint jog = 0;
 
-#ifdef DEBUG
-   fprintf(stdout, "sjog_spic_read_jog: spic_fd=%d\n", spic_fd);
-#endif
+   D("sjog_spic_read_jog: spic_fd=%d\n", spic_fd);
 
    if (read(spic_fd, (gchar *) & jog, sizeof(gint)) < 0)
    {
