@@ -8,10 +8,7 @@
 int
 sjog_volume_timer_callback(gpointer * data)
 {
-
-#ifdef DEBUG
-   fprintf(stdout, "sjog_volume_timer_callback\n");
-#endif
+   D_ENTER;
 
    sjog_volume_hide();
 
@@ -28,10 +25,7 @@ int
 sjog_volume_signal_delete_event_callback(GtkWidget * widget, GdkEvent * event,
                                          gpointer * data)
 {
-
-#ifdef DEBUG
-   fprintf(stdout, "sjog_volume_signal_delete_event_callback\n");
-#endif
+   D_ENTER;
 
    sjog_volume_hide();
 
